from __future__ import absolute_import
from . import utils
from . import paths
from . import setup_hd_glio

print("\n########################")
print("If you are using hd-bet, please cite the following papers:\n")
print("Kickingereder P, Isensee F, Tursunova I, Petersen J, Neuberger U, Bonekamp D, Brugnara G, Schell M, Kessler T, "
      "Foltyn M, Harting I, Sahm F, Prager M, Nowosielski M, Wick A, Nolden M, Radbruch A, Debus J, Schlemmer HP, "
      "Heiland S, Platten M, von Deimling A, van den Bent MJ, Gorlia T, Wick W, Bendszus M, Maier-Hein KH. Automated "
      "quantitative tumour response assessment of MRI in neuro-oncology with artificial neural networks: a "
      "multicentre, retrospective study. Lancet Oncol. 2019 May;20(5):728-740. "
      "https://doi.org/10.1016/S1470-2045(19)30098-1\n")
print("Isensee, Fabian, et al. \"nnU-Net: Breaking the Spell on Successful Medical Image Segmentation.\" "
      "arXiv preprint arXiv:1904.08128 (2019). (https://arxiv.org/abs/1904.08128)\n")
